@@ -2,7 +2,7 @@
  * acss.c: Functions for DVD authentication and descrambling
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: acss.c,v 1.4 2004/03/01 21:36:17 hshoexer Exp $
+ * $Id: acss.c,v 1.5 2005/04/17 16:47:10 hshoexer Exp $
  *
  * Author: Stphane Borel <stef@via.ecp.fr>
  *         Hkan Hjort <d95hjort@dtek.chalmers.se>
@@ -679,8 +679,7 @@ static void genseed(libdvd_t libdvd, uint8_t *value, int offset)
 
     RMD160Init(&ctx);
     RMD160Update(&ctx, libdvd->psz_challenge, strlen(libdvd->psz_challenge));
-    RMD160Update(&ctx, (unsigned char*)&salts[offset * 2],
-		    sizeof(unsigned long));
+    RMD160Update(&ctx, (unsigned char*)&salts[offset * 2], sizeof(u_int32_t));
     RMD160Final(digest, &ctx);
 
     for (i = 0; i < 3; i++)
@@ -688,8 +687,7 @@ static void genseed(libdvd_t libdvd, uint8_t *value, int offset)
 
     RMD160Init(&ctx);
     RMD160Update(&ctx, libdvd->psz_challenge, strlen(libdvd->psz_challenge));
-    RMD160Update(&ctx, (unsigned char*)&salts[offset * 2 + 1],
-		    sizeof(unsigned long));
+    RMD160Update(&ctx, (unsigned char*)&salts[offset * 2 + 1], sizeof(u_int32_t));
     RMD160Final(digest, &ctx);
 	
     for (i = 0; i < 2; i++)
