@@ -5,7 +5,7 @@
  *          Hkan Hjort <d95hjort@dtek.chalmers.se>
  *
  * Copyright (C) 1998-2002 VideoLAN
- * $Id: libdvd.c,v 1.3 2004/03/01 21:36:17 hshoexer Exp $
+ * $Id: libdvd.c,v 1.4 2005/04/17 16:47:10 hshoexer Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -322,42 +322,11 @@ extern libdvd_t libdvd_open ( char *psz_target )
         }
     }
 
-    /*
-     *  Open device
-     */
-    i_ret = _libdvd_open( libdvd );
-    if( i_ret < 0 )
-    {
-        free( libdvd->psz_device );
-        free( libdvd );
-        return NULL;
-    }
-
-    libdvd->b_scrambled = 1; /* Assume the worst */
-    libdvd->b_ioctls = _libdvd_use_ioctls( libdvd );
-
-    if( libdvd->b_ioctls )
-    {
-        i_ret = _libdvd_test( libdvd );
-        if( i_ret < 0 )
-        {
-            /* Disable the CSS ioctls and hope that it works? */
-            _libdvd_debug( libdvd,
-                           "could not check whether the disc was scrambled" );
-            libdvd->b_ioctls = 0;
-        }
-        else
-        {
-            _libdvd_debug( libdvd, i_ret ? "disc is scrambled"
-                                         : "disc is unscrambled" );
-            libdvd->b_scrambled = i_ret;
-        }
-    }
-
     /*
      * Get Challenge.  If available, use cached challenge.  Otherwise request
      * on from user.
      */
+    bzero(libdvd->psz_challenge, sizeof(libdvd->psz_challenge));
     snprintf(libdvd->psz_challengefile, PATH_MAX, "%s/challenge", psz_cache);
 
     i_savechallenge = 0;
@@ -388,13 +357,44 @@ extern libdvd_t libdvd_open ( char *psz_target )
 	    return NULL;
 	}
 
-	strlcpy(libdvd->psz_challenge, tmp,
-		      sizeof(libdvd->psz_challenge));
+	strlcpy(libdvd->psz_challenge, tmp, sizeof(libdvd->psz_challenge));
 
 	/* We do this later, as $HOME/.libdvd/ might not yet exist. */
 	i_savechallenge = 1;
     }
 
+    /*
+     *  Open device
+     */
+    i_ret = _libdvd_open( libdvd );
+    if( i_ret < 0 )
+    {
+        free( libdvd->psz_device );
+        free( libdvd );
+        return NULL;
+    }
+
+    libdvd->b_scrambled = 1; /* Assume the worst */
+    libdvd->b_ioctls = _libdvd_use_ioctls( libdvd );
+
+    if( libdvd->b_ioctls )
+    {
+        i_ret = _libdvd_test( libdvd );
+        if( i_ret < 0 )
+        {
+            /* Disable the CSS ioctls and hope that it works? */
+            _libdvd_debug( libdvd,
+                           "could not check whether the disc was scrambled" );
+            libdvd->b_ioctls = 0;
+        }
+        else
+        {
+            _libdvd_debug( libdvd, i_ret ? "disc is scrambled"
+                                         : "disc is unscrambled" );
+            libdvd->b_scrambled = i_ret;
+        }
+    }
+
     /* If disc is CSS protected and the ioctls work, authenticate the drive */
     if( libdvd->b_scrambled && libdvd->b_ioctls )
     {
@@ -515,7 +515,7 @@ extern libdvd_t libdvd_open ( char *psz_target )
 	    if (i_ret < (int)strlen(libdvd->psz_challenge)) {
 		_libdvd_error(libdvd, "failed to save challenge");
 
-		/* Just try to get rid of the cache file */
+		/* Just try to get rid of the challenge file */
 		unlink(libdvd->psz_challengefile);
 	    }
 
