@@ -2,7 +2,7 @@
  * scrambletables.h: CSS Tables for DVD unscrambling
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: scrambletables.h,v 1.1 2004/02/29 01:06:40 hshoexer Exp $
+ * $Id: scrambletables.h,v 1.2 2005/04/17 16:47:10 hshoexer Exp $
  *
  * Author: Stphane Borel <stef@via.ecp.fr>
  *
@@ -390,7 +390,7 @@ static uint8_t p_crypt_tab3[ 288 ] =
     0xC3, 0x82, 0xC9, 0x15, 0x57, 0x16, 0x5D, 0x81
 };
 
-static unsigned long salts[64] = 
+static u_int32_t salts[64] = 
 {
     0x00854b44, 0x0080c3a6, 0x00668282, 0x00779e09,
     0x00590b94, 0x004f3aa1, 0x002c3060, 0x00b0f631,
